@@ -56,6 +56,7 @@ __all__ = (
     "UserStatusTypeType",
     "UserTypeType",
     "ServiceName",
+    "PaginatorName",
 )
 
 
@@ -400,10 +401,12 @@ ServiceName = Literal[
     "transcribe",
     "transfer",
     "translate",
+    "voice-id",
     "waf",
     "waf-regional",
     "wafv2",
     "wellarchitected",
+    "wisdom",
     "workdocs",
     "worklink",
     "workmail",
@@ -411,3 +414,14 @@ ServiceName = Literal[
     "workspaces",
     "xray",
 ]
+PaginatorName = Literal[
+    "describe_activities",
+    "describe_comments",
+    "describe_document_versions",
+    "describe_folder_contents",
+    "describe_groups",
+    "describe_notification_subscriptions",
+    "describe_resource_permissions",
+    "describe_root_folders",
+    "describe_users",
+]
