@@ -85,32 +85,32 @@ class _PageIterator(Generic[_ItemTypeDef], PageIterator):
 
 class DescribeActivitiesPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
     """
 
     def paginate(
         self,
         *,
-        AuthenticationToken: str = None,
-        StartTime: Union[datetime, str] = None,
-        EndTime: Union[datetime, str] = None,
-        OrganizationId: str = None,
-        ActivityTypes: str = None,
-        ResourceId: str = None,
-        UserId: str = None,
-        IncludeIndirectActivities: bool = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        StartTime: Union[datetime, str] = ...,
+        EndTime: Union[datetime, str] = ...,
+        OrganizationId: str = ...,
+        ActivityTypes: str = ...,
+        ResourceId: str = ...,
+        UserId: str = ...,
+        IncludeIndirectActivities: bool = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeActivitiesResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeActivities.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeactivitiespaginator)
         """
 
 
 class DescribeCommentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
     """
 
@@ -119,18 +119,18 @@ class DescribeCommentsPaginator(Boto3Paginator):
         *,
         DocumentId: str,
         VersionId: str,
-        AuthenticationToken: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeCommentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeComments.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describecommentspaginator)
         """
 
 
 class DescribeDocumentVersionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
     """
 
@@ -138,20 +138,20 @@ class DescribeDocumentVersionsPaginator(Boto3Paginator):
         self,
         *,
         DocumentId: str,
-        AuthenticationToken: str = None,
-        Include: str = None,
-        Fields: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        Include: str = ...,
+        Fields: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeDocumentVersionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeDocumentVersions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describedocumentversionspaginator)
         """
 
 
 class DescribeFolderContentsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
     """
 
@@ -159,22 +159,22 @@ class DescribeFolderContentsPaginator(Boto3Paginator):
         self,
         *,
         FolderId: str,
-        AuthenticationToken: str = None,
-        Sort: ResourceSortTypeType = None,
-        Order: OrderTypeType = None,
-        Type: FolderContentTypeType = None,
-        Include: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        Sort: ResourceSortTypeType = ...,
+        Order: OrderTypeType = ...,
+        Type: FolderContentTypeType = ...,
+        Include: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeFolderContentsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeFolderContents.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describefoldercontentspaginator)
         """
 
 
 class DescribeGroupsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
     """
 
@@ -182,34 +182,34 @@ class DescribeGroupsPaginator(Boto3Paginator):
         self,
         *,
         SearchQuery: str,
-        AuthenticationToken: str = None,
-        OrganizationId: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        OrganizationId: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeGroupsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeGroups.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describegroupspaginator)
         """
 
 
 class DescribeNotificationSubscriptionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
     """
 
     def paginate(
-        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, OrganizationId: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeNotificationSubscriptionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeNotificationSubscriptions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describenotificationsubscriptionspaginator)
         """
 
 
 class DescribeResourcePermissionsPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
     """
 
@@ -217,51 +217,51 @@ class DescribeResourcePermissionsPaginator(Boto3Paginator):
         self,
         *,
         ResourceId: str,
-        AuthenticationToken: str = None,
-        PrincipalId: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        PrincipalId: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeResourcePermissionsResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeResourcePermissions.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeresourcepermissionspaginator)
         """
 
 
 class DescribeRootFoldersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
     """
 
     def paginate(
-        self, *, AuthenticationToken: str, PaginationConfig: PaginatorConfigTypeDef = None
+        self, *, AuthenticationToken: str, PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeRootFoldersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeRootFolders.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describerootfolderspaginator)
         """
 
 
 class DescribeUsersPaginator(Boto3Paginator):
     """
-    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
+    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers)
     [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
     """
 
     def paginate(
         self,
         *,
-        AuthenticationToken: str = None,
-        OrganizationId: str = None,
-        UserIds: str = None,
-        Query: str = None,
-        Include: UserFilterTypeType = None,
-        Order: OrderTypeType = None,
-        Sort: UserSortTypeType = None,
-        Fields: str = None,
-        PaginationConfig: PaginatorConfigTypeDef = None
+        AuthenticationToken: str = ...,
+        OrganizationId: str = ...,
+        UserIds: str = ...,
+        Query: str = ...,
+        Include: UserFilterTypeType = ...,
+        Order: OrderTypeType = ...,
+        Sort: UserSortTypeType = ...,
+        Fields: str = ...,
+        PaginationConfig: PaginatorConfigTypeDef = ...
     ) -> _PageIterator[DescribeUsersResponseTypeDef]:
         """
-        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.50/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
+        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/1.18.51/reference/services/workdocs.html#WorkDocs.Paginator.DescribeUsers.paginate)
         [Show boto3-stubs documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_workdocs/paginators.html#describeuserspaginator)
         """
